R/fct_core.R
get_limits.RdGiven a batch size and an analysis type (first or second), returns a list of the acceptance and rejection limits for that batch size and analysis type.
get_limits(batch_size, analysis)A numeric value indicating the size of the batch for which the acceptance and rejection limits are to be returned.
A string indicating the analysis type for which the acceptance and rejection limits are to be returned. Must be one of "first" or "second".
A list with two elements, named "analysis_acceptance" and "analysis_rejection", representing the acceptance and rejection limits for the specified batch size and analysis type. If the batch size or analysis type is outside the range of valid values, an error will be thrown with a message indicating the nature of the problem.
get_limits(1500, "first")
#> $analysis_acceptance
#> [1] 2
#>
#> $analysis_rejection
#> [1] 5
#>
get_limits(100, "second")
#> $analysis_acceptance
#> [1] 4
#>
#> $analysis_rejection
#> [1] 5
#>