This function uses sample data, a value column, and a categorical column to create an interactive chart.

get_mean_analysis_plot(
  batch_size,
  nominal_quantity,
  mean_val,
  std_dev,
  computed_student_dist
)

Arguments

batch_size

Number representing the batch size

nominal_quantity

Number representing the target nominal quantity

mean_val

Number representing the estimated sample mean

std_dev

Number representing the estimated sample standard deviation

computed_student_dist

Number representing the computed student dist limit

Value

An interactive control chart using plotly

Examples

get_mean_analysis_plot(100, 30, 30, 1, 0.503)