A dataset containing the maximum error tolerances for different nominal quantities, according to the specifications provided in the table.

max_errors

Format

A data frame with 7 rows and 4 variables:

lower_limit

lower limit of the nominal quantity range

upper_limit

upper limit of the nominal quantity range

percentage_over_nominal_quantity

percentage of error over nominal quantity (if available)

absolute_value

absolute value of the maximum error tolerance (if available)