A dataset containing the required sample sizes for mean analysis and the corresponding computed Student distribution using the specification on RD 1802/20XX.

mean_analysis_params

Format

A data frame with 2 rows and 4 variables:

batch_size_min

lower limit of the batch size interval

batch_size_max

upper limit of the batch size interval

sample_sizes

sample sizes required for the mean analysis for each batch size

computed_student_distribution

Student distribution computed for the corresponding sample sizes