A dataset containing the acceptance and rejection limits for batches of different sizes according to the specifications of RD 1802/20XX.

noncon_analysis_limits

Format

A data frame with 3 rows and 6 variables:

batch_size_min

The lower limit of the batch size interval.

batch_size_max

The upper limit of the batch size interval.

first_analysis_acceptance

The number of pieces that pass the first analysis and are accepted.

first_analysis_rejection

The number of pieces that fail the first analysis and are rejected.

second_analysis_acceptance

The number of pieces that pass the second analysis and are accepted.

second_analysis_rejection

The number of pieces that fail the second analysis and are rejected.