Calculates the maximum error tolerance for a given nominal quantity, based on a reference table of maximum errors.

noncon_thres_value(nominal_quantity)

Arguments

nominal_quantity

A numeric value indicating the nominal quantity for which the maximum error tolerance is to be calculated.

Value

A numeric value indicating the maximum error tolerance for the given nominal quantity. If the nominal quantity is outside the range of the reference table, the function returns an error message.

Examples

noncon_thres_value(20)
#> [1] 18.2

noncon_thres_value(5000)
#> [1] 4900