This function uses sample data, a value column, and a categorical column to create an interactive chart.
get_mean_analysis_plot(
batch_size,
nominal_quantity,
mean_val,
std_dev,
computed_student_dist
)Number representing the batch size
Number representing the target nominal quantity
Number representing the estimated sample mean
Number representing the estimated sample standard deviation
Number representing the computed student dist limit
An interactive control chart using plotly
get_mean_analysis_plot(100, 30, 30, 1, 0.503)