A dataset containing the maximum error tolerances for different nominal quantities, according to the specifications provided in the table.
max_errorsA data frame with 7 rows and 4 variables:
lower limit of the nominal quantity range
upper limit of the nominal quantity range
percentage of error over nominal quantity (if available)
absolute value of the maximum error tolerance (if available)