A dataset containing the required sample sizes for mean analysis and the corresponding computed Student distribution using the specification on RD 1802/20XX.
mean_analysis_paramsA data frame with 2 rows and 4 variables:
lower limit of the batch size interval
upper limit of the batch size interval
sample sizes required for the mean analysis for each batch size
Student distribution computed for the corresponding sample sizes