A dataset containing the acceptance and rejection limits for batches of different sizes according to the specifications of RD 1802/20XX.
noncon_analysis_limitsA data frame with 3 rows and 6 variables:
The lower limit of the batch size interval.
The upper limit of the batch size interval.
The number of pieces that pass the first analysis and are accepted.
The number of pieces that fail the first analysis and are rejected.
The number of pieces that pass the second analysis and are accepted.
The number of pieces that fail the second analysis and are rejected.