Calculates the maximum acceptable value for a given nominal quantity, based on a reference table of maximum errors.
noncon_limit_value(nominal_quantity)A numeric value indicating the nominal quantity for which the maximum acceptable value is to be calculated.
A numeric value indicating the maximum acceptable value for the given nominal quantity, which is twice the maximum error tolerance calculated by the "noncon_thres_value" function. If the nominal quantity is outside the range of the reference table, the function returns an error message.
noncon_limit_value(20)
#> [1] 16.4
noncon_limit_value(5000)
#> [1] 4800